@@ -12,9 +12,7 @@
 #include "control/controlutil.h"
 #include "control/controlid.h"
 
-#if GTKMMVER <= 240
 #include "icons/iconmanager.h"
-#endif
 
 #include "command.h"
 #include "session.h"
@@ -28,26 +26,23 @@ ArticleToolBar::ArticleToolBar() :
     SKELETON::ToolBar( ARTICLE::get_admin() ),
     m_enable_slot( true ),
 
-    m_button_drawout_and( Gtk::Stock::CUT ),
-    m_button_drawout_or( Gtk::Stock::ADD ),
-    m_button_clear_hl( Gtk::Stock::CLEAR ),
+    m_button_drawout_and( ICON::SEARCH_AND ),
+    m_button_drawout_or( ICON::SEARCH_OR ),
 
     m_button_live_play_stop( NULL )
 {
     // 検索バー
     set_tooltip( m_button_drawout_and, CONTROL::get_label_motions( CONTROL::DrawOutAnd ) );
     set_tooltip( m_button_drawout_or, CONTROL::get_label_motions( CONTROL::DrawOutOr ) );
-    set_tooltip( m_button_clear_hl, CONTROL::get_label_motions( CONTROL::HiLightOff ) );
 
     get_searchbar()->append( *get_tool_search( CORE::COMP_SEARCH_ARTICLE ) );
     get_searchbar()->append( *get_button_down_search() );
     get_searchbar()->append( *get_button_up_search() );
     get_searchbar()->append( m_button_drawout_and );
     get_searchbar()->append( m_button_drawout_or );
-    get_searchbar()->append( m_button_clear_hl );
+    get_searchbar()->append( *get_button_clear_highlight() );
     get_searchbar()->append( *get_button_close_searchbar() );
 
-    m_button_clear_hl.signal_clicked().connect( sigc::mem_fun(*this, &ArticleToolBar::slot_clear_highlight ) );
     m_button_drawout_or.signal_clicked().connect( sigc::mem_fun(*this, &ArticleToolBar::slot_drawout_or ) );
     m_button_drawout_and.signal_clicked().connect( sigc::mem_fun(*this, &ArticleToolBar::slot_drawout_and ) );
 
@@ -123,10 +118,10 @@ void ArticleToolBar::pack_buttons()
                 get_buttonbar().append( *get_button_stop() );
                 break;
 
-            case ITEM_FAVORITE:
+            case ITEM_APPENDFAVORITE:
                 get_buttonbar().append( *get_button_favorite() );
                 set_tooltip( *get_button_favorite(), CONTROL::get_label_motions( CONTROL::AppendFavorite )
-                             + "...\n\nスレのタブをお気に入りに直接Ｄ＆Ｄしても登録可能" );
+                             + "\n\nスレのタブをお気に入りに直接Ｄ＆Ｄしても登録可能" );
 
                 break;
 
@@ -139,11 +134,11 @@ void ArticleToolBar::pack_buttons()
                 get_buttonbar().append( *get_button_close() );
                 break;
 
-            case ITEM_PREVVIEW:
+            case ITEM_BACK:
                 get_buttonbar().append( *get_button_back() );
                 break;
 
-            case ITEM_NEXTVIEW:
+            case ITEM_FORWARD:
                 get_buttonbar().append( *get_button_forward() );
                 break;
 
@@ -153,11 +148,7 @@ void ArticleToolBar::pack_buttons()
 
             case ITEM_LIVE:
                 if( ! m_button_live_play_stop ){
-#if GTKMMVER <= 240
-                    m_button_live_play_stop = Gtk::manage( new SKELETON::ImgToggleToolButton( ICON::PLAY ) );
-#else
-                    m_button_live_play_stop = Gtk::manage( new SKELETON::ImgToggleToolButton( Gtk::Stock::MEDIA_PLAY ) );
-#endif
+                    m_button_live_play_stop = Gtk::manage( new SKELETON::ImgToggleToolButton( ICON::LIVE ) );
                     set_tooltip( *m_button_live_play_stop, CONTROL::get_label_motions( CONTROL::LiveStartStop ) );
                     m_button_live_play_stop->set_label( CONTROL::get_label( CONTROL::LiveStartStop ) );
                     m_button_live_play_stop->signal_clicked().connect( sigc::mem_fun(*this, &ArticleToolBar::slot_live_play_stop ) );
@@ -206,17 +197,6 @@ void ArticleToolBar::slot_drawout_or()
 }
 
 
-//
-// ハイライト解除
-//
-void ArticleToolBar::slot_clear_highlight()
-{
-    if( ! m_enable_slot ) return;    
-
-    ARTICLE::get_admin()->set_command( "clear_highlight", get_url() );
-}
-
-
 //
 // 実況開始/停止
 //
@@ -226,35 +206,3 @@ void ArticleToolBar::slot_live_play_stop()
 
     ARTICLE::get_admin()->set_command( "live_start_stop", get_url() );
 }
-
-
-/////////////////////////////
-
-// 簡易版
-
-
-ArticleToolBarSimple::ArticleToolBarSimple() :
-    SKELETON::ToolBar( ARTICLE::get_admin() )
-{
-    // 検索バー    
-    get_searchbar()->append( *get_tool_search( CORE::COMP_SEARCH_ARTICLE ) );
-    get_searchbar()->append( *get_button_down_search() );
-    get_searchbar()->append( *get_button_up_search() );
-    get_searchbar()->append( *get_button_close_searchbar() );
-
-    pack_buttons();
-}
-
-
-//
-// ボタンのパッキング
-//
-void ArticleToolBarSimple::pack_buttons()
-{
-    pack_transparent_separator();
-    get_buttonbar().append( *get_label() );
-    get_buttonbar().append( *get_button_close() );
-
-    set_relief();
-    show_all_children();
-}
