@@ -24,6 +24,8 @@ AboutConfigDiagStr::AboutConfigDiagStr( Gtk::Window* parent, std::string* value,
     get_vbox()->set_spacing( 8 );
     get_vbox()->pack_start( m_hbox );
 
+    set_activate_entry( m_entry );
+
     set_title( "文字列設定" );
     show_all_children();
 }
@@ -59,6 +61,8 @@ AboutConfigDiagInt::AboutConfigDiagInt( Gtk::Window* parent, int* value, const i
     get_vbox()->set_spacing( 8 );
     get_vbox()->pack_start( m_hbox );
 
+    set_activate_entry( m_entry );
+
     set_title( "整数値設定" );
     show_all_children();
 }
@@ -81,7 +85,7 @@ void AboutConfigDiagInt::slot_default()
 
 AboutConfigDiagBool::AboutConfigDiagBool( Gtk::Window* parent, bool* value, const bool defaultval )
     : SKELETON::PrefDiag( parent, "", true ), m_value( value ), m_defaultval( defaultval ),
-      m_radio_true( "true" ), m_radio_false( "false" ),  m_button_default( "デフォルト" )
+      m_radio_true( "はい" ), m_radio_false( "いいえ" ),  m_button_default( "デフォルト" )
 {
     m_radio_true.set_group( m_radiogroup );
     m_radio_false.set_group( m_radiogroup );
