@@ -101,6 +101,9 @@ namespace CONFIG
         std::string cookie_hap;
         std::string cookie_hap_bbspink;
 
+        // 2chの過去ログ取得時にofflaw2を使用する
+        bool use_offlaw2_2ch;
+
         // リンクをクリックしたときに実行するコマンド
         std::string command_openurl;
 
@@ -230,7 +233,7 @@ namespace CONFIG
         // カテゴリを開いたときにツリービューをスクロールする
         bool scroll_tree;
 
-        // ツリービューの選択を、表示中のビューと同期するか ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
+        // ツリービューの選択を表示中のビューと同期する ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
         int select_item_sync;
 
         // 各ビューと枠との間の余白
@@ -409,9 +412,12 @@ namespace CONFIG
         // タブ上でマウスホイールを回転してタブを切り替える
         bool switchtab_wheel;
 
-        // ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+        // 他のビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
         int newtab_pos;
 
+        // ツリービューで選択したビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+        int opentab_pos;
+
         // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
         int boardnexttab_pos;
 
