@@ -64,8 +64,9 @@ namespace CONFIG
     // カテゴリを開いたときにツリービューをスクロールする
     const bool get_scroll_tree();
 
-    // ツリービューの選択を、表示中のビューと同期するか ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
+    // ツリービューの選択を表示中のビューと同期する ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
     const int get_select_item_sync();
+    void set_select_item_sync( const int sync );
 
     // 各ビューと枠との間の余白
     const int get_view_margin();
@@ -193,6 +194,9 @@ namespace CONFIG
     void set_cookie_hap( const std::string& cookie_hap );
     void set_cookie_hap_bbspink( const std::string& cookie_hap );
 
+    // 2chの過去ログ取得時にofflaw2を使用する
+    const bool get_use_offlaw2_2ch();
+
     // リンクをクリックしたときに実行するコマンド
     const std::string& get_command_openurl();
     void set_command_openurl( const std::string& command );
@@ -459,9 +463,12 @@ namespace CONFIG
     // タブ上でマウスホイールを回転してタブを切り替える
     const bool get_switchtab_wheel();
 
-    // ビュー内から他のビューを開いたときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+    // 他のビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
     const int get_newtab_pos();
 
+    // ツリービューで選択したビューを開くときのタブの位置 ( 0: 一番右端 1:右隣 2:左隣 )
+    const int get_opentab_pos();
+
     // 次スレ検索を開くときのタブの位置 ( 0: 次スレ検索タブ 1:新しいタブ 2:アクティブなタブを置き換え )
     const int get_boardnexttab_pos();
 
