@@ -240,6 +240,7 @@ namespace CORE
         ///
         void slot_toggle_since( const int mode );
         void slot_toggle_write( const int mode );
+        void slot_toggle_access( const int mode );
         void slot_toggle_toolbarmain();
         void slot_toggle_toolbarpos( const int pos );
         void slot_toggle_toolbarbbslist();
@@ -274,6 +275,7 @@ namespace CORE
         void slot_image_pref();
         void slot_toggle_restore_views();
         void slot_toggle_fold_message();
+        void slot_toggle_select_item_sync();
         void slot_toggle_save_post_log();
         void slot_toggle_save_post_history();
         void slot_toggle_use_mosaic();
