@@ -438,9 +438,9 @@ const std::string& ArticleBase::get_access_date()
     if( m_access_time.tv_sec ){
 
         if( m_access_date.empty() 
-            || SESSION::get_col_write_time() == MISC::TIME_PASSED ){
+            || SESSION::get_col_access_time() == MISC::TIME_PASSED ){
         
-        	m_access_date = MISC::timettostr( m_access_time.tv_sec, SESSION::get_col_write_time() );
+            m_access_date = MISC::timettostr( m_access_time.tv_sec, SESSION::get_col_access_time() );
         }
     }
 
@@ -1166,8 +1166,8 @@ void ArticleBase::download_dat( const bool check_update )
 
     if( SESSION::is_online() && tv.tv_sec ) m_check_update_time = tv;
 
-    // DAT落ちしていてログイン中で無い時はロードしない
-    if( ( m_status & STATUS_OLD ) && ! CORE::get_login2ch()->login_now() ){
+    // DAT落ちしていてロードしない場合
+    if( ( m_status & STATUS_OLD ) && ! is_load_olddat() ) {
 #ifdef _DEBUG
         std::cout << "old !\n";
 #endif       
