@@ -112,7 +112,10 @@ namespace DBTREE
         void set_key( const std::string& key ){ m_key = key; }
         void set_since_time( const time_t since ){ m_since_time = since; }
         void set_is_924( const bool is924 ){ m_924 = is924; }
-        
+
+        // dat落ちしたスレをロードするか
+        virtual const bool is_load_olddat(){ return false; }
+
       public:
 
         ArticleBase( const std::string& datbase, const std::string& id, bool cached );
@@ -237,6 +240,7 @@ namespace DBTREE
         const std::string get_access_time_str();
         const time_t& get_access_time() const { return m_access_time.tv_sec; } // 秒
         const std::string& get_access_date(); // string型
+        void reset_access_date(){ m_access_date = std::string(); }
 
         // 最終書き込み時間
         const time_t& get_write_time() const { return m_write_time.tv_sec; } // 秒
