@@ -90,7 +90,7 @@ const bool Board2chCompati::is_valid( const std::string& filename )
 //書き込み用クッキー作成
 const std::string Board2chCompati::cookie_for_write()
 {
-    std::list< std::string > list_cookies = BoardBase::list_cookies_for_write();
+    const std::list< std::string > list_cookies = BoardBase::list_cookies_for_write();
     if( list_cookies.empty() ) return std::string();
 
 #ifdef _DEBUG
@@ -104,34 +104,34 @@ const std::string Board2chCompati::cookie_for_write()
     const bool usemigemo = false;
     const bool wchar = false;
 
-    std::string str_expire;
-    std::string query_expire = "expires=([^;]*)";
+    std::string cookie_expire;
+    std::string cookie_path;
+    std::string cookie_pon;
+    std::string cookie_hap = get_hap();
+    std::string cookie_name;
+    std::string cookie_mail;
 
-    std::string str_path;
-    std::string query_path = "path=([^;]*)";
+    const std::string query_expire = "expires=([^;]*)";
+    const std::string query_path = "path=([^;]*)";
+    const std::string query_pon = "PON=([^;]*)?";
+    const std::string query_hap = "HAP=([^;]*)?";
+    const std::string query_name = "NAME=([^;]*)?";
+    const std::string query_mail = "MAIL=([^;]*)?";
 
     bool use_pon = false;
-    std::string str_pon;
-    std::string query_pon = "PON=([^;]*)?";
-
+    bool use_hap = ! cookie_hap.empty();
     bool use_name = false;
-    std::string str_name;
-    std::string query_name = "NAME=([^;]*)?";
-
     bool use_mail = false;
-    std::string str_mail;
-    std::string query_mail = "MAIL=([^;]*)?";
 
-    std::list< std::string >::iterator it = list_cookies.begin();
+    std::list< std::string >::const_iterator it = list_cookies.begin();
 
     // expire と path は一つ目のcookieから取得
-    if( regex.exec( query_expire, (*it), offset, icase, newline, usemigemo, wchar ) ) str_expire = regex.str( 1 );
-    if( regex.exec( query_path, (*it), offset, icase, newline, usemigemo, wchar ) ) str_path = regex.str( 1 );
+    if( regex.exec( query_expire, (*it), offset, icase, newline, usemigemo, wchar ) ) cookie_expire = regex.str( 1 );
+    if( regex.exec( query_path, (*it), offset, icase, newline, usemigemo, wchar ) ) cookie_path = regex.str( 1 );
 
-    // その他は iterateして取得
     for( ; it != list_cookies.end(); ++it ){
 
-        std::string tmp_cookie = MISC::Iconv( (*it), get_charset(), "UTF-8" );
+        const std::string tmp_cookie = MISC::Iconv( (*it), get_charset(), "UTF-8" );
 
 #ifdef _DEBUG
         std::cout << tmp_cookie << std::endl;
@@ -139,35 +139,47 @@ const std::string Board2chCompati::cookie_for_write()
 
         if( regex.exec( query_pon, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
             use_pon = true;
-            str_pon = regex.str( 1 );
+            cookie_pon = regex.str( 1 );
+        }
+        if( ! use_hap && regex.exec( query_hap, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
+            use_hap = true;
+            cookie_hap = regex.str( 1 );
         }
         if( regex.exec( query_name, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
             use_name = true;
-            str_name = MISC::charset_url_encode( regex.str( 1 ), get_charset() );
+            cookie_name = MISC::charset_url_encode( regex.str( 1 ), get_charset() );
         }
         if( regex.exec( query_mail, tmp_cookie, offset, icase, newline, usemigemo, wchar ) ){
             use_mail = true;
-            str_mail = MISC::charset_url_encode( regex.str( 1 ), get_charset() );
+            cookie_mail = MISC::charset_url_encode( regex.str( 1 ), get_charset() );
         }
     }
 
+    // PONを取得していないときはHAPを送らない
+    if( ! use_pon || cookie_pon.empty() ){
+        use_hap = false;
+        cookie_hap = std::string();
+    }
+
 #ifdef _DEBUG
-    std::cout << "expire = " << str_expire << std::endl
-              << "path = " << str_path << std::endl    
-              << "pon = " << str_pon << std::endl
-              << "name = " << str_name << std::endl
-              << "mail = " << str_mail << std::endl;
+    std::cout << "expire = " << cookie_expire << std::endl
+              << "path = " << cookie_path << std::endl    
+              << "pon = " << cookie_pon << " " << use_pon << std::endl
+              << "hap = " << cookie_hap << " " << use_hap << std::endl
+              << "name = " << cookie_name << " " << use_name << std::endl
+              << "mail = " << cookie_mail << " " << use_mail << std::endl;
 #endif    
 
     std::string cookie;
 
-    if( use_name ) cookie += "NAME=" + str_name + "; ";
-    if( use_mail ) cookie += "MAIL=" + str_mail + "; ";
-    if( use_pon ) cookie += "PON=" + str_pon + "; ";
+    if( use_pon ) cookie += "PON=" + cookie_pon + "; ";
+    if( use_hap ) cookie += "HAP=" + cookie_hap + "; ";
+    if( use_name ) cookie += "NAME=" + cookie_name + "; ";
+    if( use_mail ) cookie += "MAIL=" + cookie_mail + "; ";
 
     if( cookie.empty() ) return std::string();
 
-    cookie += "expires=" + str_expire + "; path=" + str_path;
+    cookie += "expires=" + cookie_expire + "; path=" + cookie_path;
 
 #ifdef _DEBUG
     std::cout << "cookie = " << cookie << std::endl;
@@ -323,9 +335,7 @@ void Board2chCompati::parse_subject( const char* str_subject_txt )
     std::cout << "Board2chCompati::parse_subject\n";
 #endif 
 
-    const int max_subject = 512;
     const char* pos = str_subject_txt;
-    char str_tmp[ max_subject ];
 
     while( *pos != '\0' ){
         
@@ -348,8 +358,8 @@ void Board2chCompati::parse_subject( const char* str_subject_txt )
         }
         if( *pos == '\n' ) { ++pos; continue; }
 
-        while( *pos != '<' ) ++pos;
-        ++pos;
+        while( *pos != '\0' && *pos != '<' ) ++pos;
+        if( *pos != '\0' ) ++pos;
         if( *pos != '>' ){
             MISC::ERRMSG( "subject.txt is broken" );
             break;
@@ -371,14 +381,18 @@ void Board2chCompati::parse_subject( const char* str_subject_txt )
             MISC::ERRMSG( "subject.txt is broken" );
             break;
         }
-        lng_subject = MIN( ( int )( pos - str_subject ), max_subject );
+        lng_subject = ( int )( pos - str_subject );
         
         // レス数取得
         ++pos;
         int i = 0;
-        while( *pos != ')' && *pos != '\0' && *pos != '\n' && i < 16 ) str_num[ i++ ] = *( pos++ );
+        while( '0' <= *pos && *pos <= '9' && i < 16 ) str_num[ i++ ] = *( pos++ );
 
         // 壊れてる
+        if( i == 0 ){
+            MISC::ERRMSG( "subject.txt is broken (res)" );
+            break;
+        }
         if( *pos == '\0' ) break;
         if( *pos == '\n' ) { ++pos; continue; }
 
@@ -388,14 +402,13 @@ void Board2chCompati::parse_subject( const char* str_subject_txt )
         // id, subject, number 取得
         ARTICLE_INFO artinfo;
 
-        memcpy( str_tmp, str_id_dat, lng_id_dat );
-        str_tmp[ lng_id_dat ] = '\0';
-        artinfo.id = str_tmp;
+        artinfo.id.assign( str_id_dat, lng_id_dat );
+
+        if( str_subject[ lng_subject-1 ] == ' ' ){
+            lng_subject--;  // 2chのsubject.txtは()の前に空白が一つ入る
+        }
+        artinfo.subject.assign( str_subject, lng_subject );
 
-        memcpy( str_tmp, str_subject, lng_subject );
-        if( str_tmp[ lng_subject-1 ] == ' ' ) lng_subject--;  // 2chのsubject.txtは()の前に空白が一つ入る
-        str_tmp[ lng_subject ] = '\0';
-        artinfo.subject = str_tmp;
         if( exist_amp ){
             artinfo.subject = MISC::replace_str( artinfo.subject, "&lt;", "<" );
             artinfo.subject = MISC::replace_str( artinfo.subject, "&gt;", ">" );
