@@ -48,13 +48,15 @@ namespace DBTREE
         virtual const std::string default_noname();
         virtual const int line_number();
         virtual const int message_count();
+        virtual const std::string get_unicode();
 
       private:
 
-        virtual bool is_valid( const std::string& filename );
+        virtual const bool is_valid( const std::string& filename );
 
         virtual ArticleBase* append_article( const std::string& datbase, const std::string& id, const bool cached );
         virtual void parse_subject( const char* str_subject_txt );
+        virtual void regist_article( const bool is_online );
 
         virtual void load_rule_setting();
         virtual void download_rule_setting();
