@@ -123,12 +123,6 @@ bool BoardBase::empty()
 }
 
 
-void BoardBase::set_check_noname( bool check )
-{
-    m_check_noname = check;
-}
-
-
 //
 // url がこの板のものかどうか
 //
@@ -157,11 +151,18 @@ void BoardBase::update_name( const std::string& name )
 
 
 // ユーザエージェント
+// ダウンロード用
 const std::string& BoardBase::get_agent()
 {
     return CONFIG::get_agent_for_data();
 }
 
+// 書き込み用
+const std::string& BoardBase::get_agent_w()
+{
+    return get_agent();
+}
+
 
 // 読み込み用プロキシ
 const std::string BoardBase::get_proxy_host()
@@ -268,6 +269,13 @@ const int BoardBase::message_count()
 }
 
 
+// 特殊文字書き込み可能か( pass なら可能、 change なら不可 )
+const std::string BoardBase::get_unicode()
+{
+    return "";
+}
+
+
 //書き込み用クッキー
 const std::string BoardBase::cookie_for_write()
 {
@@ -277,6 +285,59 @@ const std::string BoardBase::cookie_for_write()
 }
 
 
+//書き込み用クッキーのセット
+void BoardBase::set_list_cookies_for_write( const std::list< std::string >& list_cookies )
+{
+#ifdef _DEBUG
+    std::cout << "BoardBase::set_list_cookies_for_write\n";
+#endif
+
+    std::list< std::string >::const_iterator it = list_cookies.begin();
+    for( ; it != list_cookies.end(); ++it ){
+
+        const std::string cookie = MISC::remove_space( *it );
+
+#ifdef _DEBUG        
+        std::cout << "cookie = " << cookie << std::endl;
+#endif
+
+        std::string key;
+        const size_t n = cookie.find( "=" );
+        if( n != std::string::npos ) key = cookie.substr( 0, n+1 );
+
+        // 更新
+        // クッキーの削除は未実装
+        if( ! key.empty() && key.find( ";" ) == std::string::npos ){
+             
+#ifdef _DEBUG        
+            std::cout << "key = " << key << std::endl;
+#endif
+            std::list< std::string >::iterator it2 = m_list_cookies_for_write.begin();
+            for( ; it2 != m_list_cookies_for_write.end(); ++it2 ){
+
+                if( (*it2).find( key ) == 0 ){
+#ifdef _DEBUG        
+                    std::cout << "found\n";
+#endif
+                    (*it2) = cookie;
+                    break;
+                }
+            }
+            if( it2 == m_list_cookies_for_write.end() ) m_list_cookies_for_write.push_back( cookie );
+        }
+    }
+
+#ifdef _DEBUG        
+    std::cout << "result:\n";
+    it = m_list_cookies_for_write.begin();
+    for( ; it != m_list_cookies_for_write.end(); ++it ) std::cout << (*it) << std::endl;
+#endif
+
+    update_hap();
+}
+
+
+
 void BoardBase::clear()
 {
     if( m_rawdata ) free( m_rawdata );
@@ -402,6 +463,27 @@ void BoardBase::clear_all_post_history()
 }
 
 
+//
+// 全スレの書き込み時間とスレ立て時間の文字列をリセット
+//
+void BoardBase::reset_all_since_date()
+{
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->reset_since_date();
+}
+
+void BoardBase::reset_all_write_date()
+{
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->reset_write_date();
+}
+
+void BoardBase::reset_all_access_date()
+{
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->reset_access_date();
+}
+
 
 //
 // 最大レス数をセット
@@ -462,6 +544,10 @@ void BoardBase::update_url( const std::string& root, const std::string& path_boa
     m_root = root;
     m_path_board = path_board;
 
+    m_query_dat = std::string();
+    m_query_cgi = std::string();
+    m_query_kako = std::string();
+
     // modified 時刻をリセット
     // 自動移転処理後に bbsmenu.html を読み込んだときに、bbsmenu.html の
     // アドレスが古いと二度と自動移転処理しなくなる
@@ -482,13 +568,19 @@ void BoardBase::update_url( const std::string& root, const std::string& path_boa
 //
 // (例) url =  "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345/12-15"のとき、
 //
-// 戻り値 : "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15
+// 戻り値 : "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15, num_str = "12-15"
 //
 const std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str )
 {
     if( empty() ) return std::string();
 
     JDLIB::Regex regex;
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
     std::string id; // スレッドのID
 
 #ifdef _DEBUG
@@ -497,22 +589,30 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
     
     num_from = num_to = 0;
 
-    // dat 型
-    const std::string datpath = MISC::replace_str( url_datpath(), "?", "\\?" );
-    const std::string query_dat = "^ *(http://.+" + datpath  + ")([1234567890]+" + get_ext() + ") *$";
+    if( m_query_dat.empty() ){
 
-    // read.cgi型
-    const std::string cgipath = MISC::replace_str( url_readcgipath(), "?", "\\?" );
-    const std::string query_cgi = "^ *(http://.+" + cgipath + ")([1234567890]+)/?r?(l50)?([1234567890]+)?(-)?([1234567890]+)?.*$";
+        // dat 型
+        const std::string datpath = MISC::replace_str( url_datpath(), "?", "\\?" );
+        m_query_dat = "^ *(http://.+" + datpath  + ")([1234567890]+" + get_ext() + ") *$";
+
+        // read.cgi型
+        const std::string cgipath = MISC::replace_str( url_readcgipath(), "?", "\\?" );
+        m_query_cgi = "^ *(http://.+" + cgipath + ")([1234567890]+)/?r?(l50)?([1234567890]+)?(-)?([1234567890]+)?.*$";
+
+        // 過去ログかどうか
+        const std::string pathboard = MISC::replace_str( m_path_board, "?", "\\?" );
+        m_query_kako = "^ *(http://.+)" + pathboard  + "/kako(/[1234567890]+)?/[1234567890]+/([1234567890]+).html *$";
 
 #ifdef _DEBUG
-    std::cout << "query_dat = " << query_dat << std::endl;
-    std::cout << "query_cgi = " << query_cgi << std::endl;
+        std::cout << "query_dat = " << m_query_dat << std::endl;
+        std::cout << "query_cgi = " << m_query_cgi << std::endl;
+        std::cout << "query_kako = " << m_query_kako << std::endl;
 #endif
+    }
 
-    if( regex.exec( query_dat , url ) ) id = regex.str( 2 );
+    if( regex.exec( m_query_dat , url, offset, icase, newline, usemigemo, wchar ) ) id = regex.str( 2 );
 
-    else if( regex.exec( query_cgi , url ) ){
+    else if( regex.exec( m_query_cgi , url, offset, icase, newline, usemigemo, wchar ) ){
 
         id = regex.str( 2 ) + get_ext(); 
 
@@ -544,13 +644,10 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
     // どちらでもない(スレのURLでない)場合
     else{
 
-        // 過去ログかどうか
-        const std::string pathboard = MISC::replace_str( m_path_board, "?", "\\?" );
-        const std::string query_kako = "^ *(http://.+)" + pathboard  + "/kako(/[1234567890]+)?/[1234567890]+/([1234567890]+).html *$";
 #ifdef _DEBUG
-        std::cout << "query_kako = " << query_kako << std::endl;
+        std::cout << "query_kako = " << m_query_kako << std::endl;
 #endif
-        if( regex.exec( query_kako , url ) ){
+        if( regex.exec( m_query_kako , url, offset, icase, newline, usemigemo, wchar ) ){
 
             std::string url_tmp = regex.str( 1 ) + url_datpath() + regex.str( 3 ) + get_ext();
 #ifdef _DEBUG
@@ -1058,8 +1155,14 @@ void BoardBase::receive_finish()
             std::cout << m_rawdata << std::endl;
 #endif
             JDLIB::Regex regex;
+            const size_t offset = 0;
+            const bool icase = false;
+            const bool newline = true;
+            const bool usemigemo = false;
+            const bool wchar = false;
+
             std::string query = ".*window.location.href=\"([^\"]*)\".*";
-            if( regex.exec( query, m_rawdata ) ){
+            if( regex.exec( query, m_rawdata, offset, icase, newline, usemigemo, wchar ) ){
 
                 const std::string new_url = regex.str( 1 );
                 int ret = Gtk::RESPONSE_YES;
@@ -1114,7 +1217,7 @@ void BoardBase::receive_finish()
         // ちなみにdatの読み込みでリダイレクト(302)が返ってきたときは、移転かdat落ちか判断出来ないので注意
         // NodeTree2ch::receive_finish()も参照せよ
         //
-        if( get_code() == HTTP_REDIRECT ){
+        if( get_code() == HTTP_REDIRECT || get_code() == HTTP_MOVED_PERM ){
 
             set_date_modified( std::string() );
 
@@ -1219,7 +1322,7 @@ void BoardBase::receive_finish()
         }
 
         // DAT落ちなどでsubject.txtに無いスレもsubjectリストに加える
-        if( CONFIG::get_show_oldarticle() ){
+        if( CONFIG::get_show_oldarticle() || m_show_oldlog ){
 
             ArticleHashIterator it = m_hash_article->begin();
             for( ; it != m_hash_article->end(); ++it ){
@@ -1432,6 +1535,11 @@ const bool BoardBase::is_abone_thread( ArticleBase* article )
     if( !check_number && !check_hour && !check_thread && !check_word && !check_regex && !check_word_global && !check_regex_global ) return false;
 
     JDLIB::Regex regex;
+    const size_t offset = 0;
+    const bool icase = CONFIG::get_abone_icase();
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = CONFIG::get_abone_wchar();
 
     // レスの数であぼーん
     if( check_number ) if( article->get_number() >= check_number ) return true;
@@ -1465,7 +1573,7 @@ const bool BoardBase::is_abone_thread( ArticleBase* article )
     if( check_regex ){
         std::list< std::string >::iterator it = m_list_abone_regex_thread.begin();
         for( ; it != m_list_abone_regex_thread.end(); ++it ){
-            if( regex.exec( *it, article->get_subject() ) ) return true;
+            if( regex.exec( *it, article->get_subject(), offset, icase, newline, usemigemo, wchar ) ) return true;
         }
     }
 
@@ -1481,7 +1589,7 @@ const bool BoardBase::is_abone_thread( ArticleBase* article )
     if( check_regex_global ){
         std::list< std::string >::iterator it = CONFIG::get_list_abone_regex_thread().begin();
         for( ; it != CONFIG::get_list_abone_regex_thread().end(); ++it ){
-            if( regex.exec( *it, article->get_subject() ) ) return true;
+            if( regex.exec( *it, article->get_subject(), offset, icase, newline, usemigemo, wchar ) ) return true;
         }
     }
 
@@ -1503,36 +1611,47 @@ void BoardBase::remove_old_abone_thread()
 
 #ifdef _DEBUG
     std::cout << "BoardBase::remove_old_abone_thread\n";
-    std::list< std::string >::const_iterator it = m_list_abone_thread.begin();
-    for( ; it != m_list_abone_thread.end(); ++it ) std::cout << ( *it ) << std::endl;
+    std::list< std::string >::const_iterator it1 = m_list_abone_thread.begin();
+    for( ; it1 != m_list_abone_thread.end(); ++it1 ) std::cout << ( *it1 ) << std::endl;
     std::cout << "->\n";
     std::list< std::string >::const_iterator it2 = m_list_abone_thread_remove.begin();
     for( ; it2 != m_list_abone_thread_remove.end(); ++it2 ) std::cout << ( *it2 ) << std::endl;
 #endif
 
-    if( CONFIG::get_remove_old_abone_thread() == 1 ){
-        m_list_abone_thread = m_list_abone_thread_remove;
-        return;
+    if( CONFIG::get_remove_old_abone_thread() == 0 ){
+
+        SKELETON::MsgCheckDiag mdiag( NULL,
+                                      "NGスレタイトルに登録したスレがdat落ちしました。\n\nNGスレタイトルから除外しますか？\n後で板のプロパティから削除する事も可能です。",
+                                      "今後表示しない(_D)",
+                                      Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+
+        mdiag.add_default_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
+        mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+
+        const int ret = mdiag.run();
+
+        // 一度いいえを選択したらあとは再起動するまでダイアログを表示しない
+        if( ret != Gtk::RESPONSE_YES ) m_cancel_remove_abone_thread = true; 
+
+        if( mdiag.get_chkbutton().get_active() ){
+
+            if( ret == Gtk::RESPONSE_YES ) CONFIG::set_remove_old_abone_thread( 1 );
+            else CONFIG::set_remove_old_abone_thread( 2 );
+        }
+
+        if( ret != Gtk::RESPONSE_YES ) return;
     }
 
-    SKELETON::MsgCheckDiag mdiag( NULL,
-                             "NGスレタイトルに登録したスレがdat落ちしました。\n\nNGスレタイトルから除外しますか？\n後で板のプロパティから削除する事も可能です。",
-                             "今後表示しない(_D)",
-                                  Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+    std::list< std::string >::iterator it = m_list_abone_thread.begin();
+    for( ; it != m_list_abone_thread.end(); ++it ){
 
-    mdiag.add_default_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-    mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+        if( std::find( m_list_abone_thread_remove.begin(), m_list_abone_thread_remove.end(), *it )
+            == m_list_abone_thread_remove.end() ){
 
-    const int ret = mdiag.run();
-    if( ret == Gtk::RESPONSE_YES ) m_list_abone_thread = m_list_abone_thread_remove;
-
-    // 一度いいえを選択したらあとは再起動するまでダイアログを表示しない
-    else m_cancel_remove_abone_thread = true; 
-
-    if( mdiag.get_chkbutton().get_active() ){
-
-        if( ret == Gtk::RESPONSE_YES ) CONFIG::set_remove_old_abone_thread( 1 );
-        else CONFIG::set_remove_old_abone_thread( 2 );
+            m_list_abone_thread.erase( it );
+            it = m_list_abone_thread.begin();
+            continue;
+        }
     }
 }
 
@@ -1678,7 +1797,13 @@ void BoardBase::set_local_proxy( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         m_local_proxy_basicauth = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         m_local_proxy = regex.str( 2 );
@@ -1697,7 +1822,13 @@ void BoardBase::set_local_proxy_w( const std::string& proxy )
 
     // basic認証
     JDLIB::Regex regex;
-    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy ) )
+    const size_t offset = 0;
+    const bool icase = false;
+    const bool newline = true;
+    const bool usemigemo = false;
+    const bool wchar = false;
+
+    if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
         m_local_proxy_basicauth_w = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
         m_local_proxy_w = regex.str( 2 );
@@ -1710,16 +1841,17 @@ void BoardBase::set_local_proxy_w( const std::string& proxy )
 //
 // ArticleBase のアドレスをリスト(list_article)にセットして返す
 // query が空の時はキャッシュにあるログを全てヒットさせる
-// 
+// bm がtrueの時、しおりが付いている(スレ一覧でしおりを付けた or レスに一つでもしおりが付いている)スレのみを対象に検索する
 //
 void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
                               const std::string& query,
                               const bool mode_or, // 今のところ無視
+                              const bool bm,
                               const bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
     )
 {
 #ifdef _DEBUG
-    std::cout << "BoardBase::search_cache " << query << std::endl;
+    std::cout << "BoardBase::search_cache " << url_subject() << std::endl;
 #endif
 
     if( empty() ) return;
@@ -1742,12 +1874,20 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
         ArticleBase* article = ( *it );
         if( ! article->is_cached() ) continue;
 
+        // しおりがついているスレだけ追加
+        if( bm ){
+            article->read_info();
+            if( ! article->is_bookmarked_thread() && ! article->get_num_bookmark() ) continue;
+        }
+
+        // 全て追加
         if( append_all ){
 
-#ifdef _DEBUG
-            std::cout << "append " << article->get_subject() << std::endl;
-#endif
             article->read_info();
+
+#ifdef _DEBUG
+            std::cout << "append " << article->get_subject() << " bm = " << article->get_num_bookmark() << std::endl;
+#endif
             list_article.push_back( article );
             continue;
         }
@@ -1766,6 +1906,7 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
             std::list< std::string >::const_iterator it_query = list_query.begin();
             for( ; it_query != list_query.end(); ++it_query ){
 
+                // 今の所 AND だけ対応
                 if( rawdata.find( *it_query ) == std::string::npos ){
                     apnd = false;
                     break;
@@ -1773,11 +1914,13 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
             }
 
             if( apnd ){
+
+                article->read_info();
+
 #ifdef _DEBUG
                 std::cout << "found word in " << url_readcgi( article->get_url(), 0, 0 ) << std::endl
                           << article->get_subject() << std::endl;
 #endif
-                article->read_info();
                 list_article.push_back( article );
             }
         }
@@ -1860,6 +2003,8 @@ void BoardBase::read_board_info()
 
     m_check_noname = cf.get_option_bool( "check_noname", false );
 
+    m_show_oldlog = cf.get_option_bool( "show_oldlog", false );
+
     std::string str_tmp;
 
     // あぼーん id は再起動ごとにリセット
@@ -1911,6 +2056,25 @@ void BoardBase::read_board_info()
     m_write_name = cf.get_option_str( "write_name", "" );
     m_write_mail = cf.get_option_str( "write_mail", "" );
 
+    if( ! m_write_name.empty()
+        && ( m_write_name == CONFIG::get_write_name()
+          || ( m_write_name == JD_NAME_BLANK && CONFIG::get_write_name().empty() ) )
+        ){
+#ifdef _DEBUG
+        std::cout << "reset name = " << m_write_name << std::endl;
+#endif
+        m_write_name = std::string();
+    }
+    if( ! m_write_mail.empty()
+        && ( m_write_mail == CONFIG::get_write_mail()
+          || ( m_write_mail == JD_MAIL_BLANK && CONFIG::get_write_mail().empty() ) )
+        ){
+#ifdef _DEBUG
+        std::cout << "reset mail = " << m_write_mail << std::endl;
+#endif
+        m_write_mail = std::string();
+    }
+
     // samba24
     m_samba_sec = cf.get_option_int( "samba_sec", 0, 0, 65535 );
 
@@ -1988,6 +2152,7 @@ void BoardBase::save_jdboard_info()
          << "view_sort_pre_column = " << m_view_sort_pre_column << std::endl
          << "view_sort_pre_mode = " << m_view_sort_pre_mode << std::endl
          << "check_noname = " << m_check_noname << std::endl
+         << "show_oldlog = " << m_show_oldlog << std::endl
 
     // IDは再起動ごとにリセット
 //         << "aboneid = " << str_abone_id << std::endl
@@ -2116,6 +2281,16 @@ void BoardBase::save_board_info()
 }
 
 
+//
+// 配下の全articlebaseクラスの情報保存
+//
+void BoardBase::save_articleinfo_all()
+{
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->save_info( false );
+}
+
+
 // 更新可能状態にしてお気に入りやスレ一覧のタブのアイコンに更新マークを表示
 // update == true の時に表示。falseなら戻す
 void BoardBase::show_updateicon( const bool update )
