@@ -55,8 +55,7 @@ namespace DBTREE
         // 鯖移転テーブル
         std::list< MOVETABLE > m_movetable;
 
-        std::string m_xml_bbsmenu;
-        XML::Document m_document;
+        XML::Document m_xml_document;
         char* m_rawdata;
         size_t m_lng_rawdata;
         std::list< DBTREE::ETCBOARDINFO > m_etcboards; // 外部板情報
@@ -82,8 +81,7 @@ namespace DBTREE
         ~Root();
 
         // 板一覧のxml
-        const std::string& xml_bbsmenu() const { return m_xml_bbsmenu; }
-        const XML::Document& xml_document() const { return m_document; }
+        const XML::Document& xml_document() const { return m_xml_document; }
 
         // 板移転
         const bool move_board( const std::string& url_old, const std::string& url_new, const bool etc );
@@ -118,6 +116,11 @@ namespace DBTREE
         // 全boardbaseクラスに、それに属する全articlebaseクラスのあぼーん状態の更新をさせる
         void update_abone_all_article();
 
+        // 全boardbaseクラスに、それに属する全articlebaseクラスの書き込み時間とスレ立て時間の文字列をリセットさせる
+        void reset_all_since_date();
+        void reset_all_write_date();
+        void reset_all_access_date();
+
         // 板が移転したかチェックする
         // 移転した時は移転後のURLを返す
         const std::string is_board_moved( const std::string& url ); // 簡易版
@@ -139,8 +142,11 @@ namespace DBTREE
         // 全板の情報ファイル読み込み
         void read_boardinfo_all();
 
+        // 全スレ情報の保存
+        void save_articleinfo_all();
+
         // 全ログ検索
-        void search_cache( std::vector< ArticleBase* >& list_article, const std::string& query, const bool mode_or, const bool& stop );
+        void search_cache( std::vector< ArticleBase* >& list_article, const std::string& query, const bool mode_or, const bool bm, const bool& stop );
 
         // 全てのスレの書き込み履歴削除
         void clear_all_post_history();
@@ -158,6 +164,7 @@ namespace DBTREE
 
         // 板のタイプを判定
         int get_board_type( const std::string& url, std::string& root, std::string& path_board, const bool etc );
+        int get_board_type( const std::string& root, const bool etc = false );
 
         // 板のタイプに合わせて板情報をセット
         bool set_board( const std::string& url, const std::string& name, const std::string& basicauth = std::string(), bool etc = false );
@@ -183,7 +190,7 @@ namespace DBTREE
         int is_moved( const std::string& root,
                        const std::string& path_board,
                        const std::string& name,
-                       BoardBase** board_old );
+                       BoardBase** board_old, bool etc );
 
         void load_cache();
         void load_etc();
