@@ -31,6 +31,9 @@ namespace DBTREE
         // 最大書き込みバイト数
         int m_message_count;
 
+        // 特殊文字書き込み
+        std::string m_unicode;
+
       public:
 
         SettingLoader( const std::string& url_boardbase );
@@ -39,6 +42,7 @@ namespace DBTREE
         const std::string& default_noname() const { return m_default_noname; }
         const int line_number() { return m_line_number; }
         const int message_count() { return m_message_count; }
+        const std::string& get_unicode() const { return m_unicode; }
 
       protected:
 
