@@ -13,6 +13,7 @@ namespace ENVIRONMENT
         WM_GNOME = 0,
         WM_XFCE,
         WM_KDE,
+        WM_LXDE,
         WM_UNKNOWN
     };
 
@@ -35,7 +36,7 @@ namespace ENVIRONMENT
 
     std::string get_jdversion();
     std::string get_distname();
-    int get_wm();
+    const int get_wm();
     std::string get_wm_str();
 	std::string get_gtkmm_version();
 	std::string get_glibmm_version();
