@@ -19,6 +19,9 @@ enum{
 };
 
 
+// 書き込みビューの名前欄の空白
+#define JD_NAME_BLANK "jd_name_blank"
+
 // 書き込みビューのメール欄の空白
 #define JD_MAIL_BLANK "jd_mail_blank"
 
@@ -29,6 +32,8 @@ enum{
 #define ITEM_NAME_HISTVIEW "スレ履歴"
 #define ITEM_NAME_HIST_BOARDVIEW "板履歴"
 #define ITEM_NAME_HIST_CLOSEVIEW "最近閉じたスレ"
+#define ITEM_NAME_HIST_CLOSEBOARDVIEW "最近閉じた板"
+#define ITEM_NAME_HIST_CLOSEIMGVIEW "最近閉じた画像"
 #define ITEM_NAME_BOARDVIEW "スレ一覧"
 #define ITEM_NAME_ARTICLEVIEW "スレビュー"
 #define ITEM_NAME_IMAGEVIEW "画像ビュー"
@@ -45,6 +50,7 @@ enum{
 #define ITEM_NAME_NEW   "新着"
 #define ITEM_NAME_SINCE "since"
 #define ITEM_NAME_LASTWRITE "最終書込"
+#define ITEM_NAME_ACCESS "最終取得"
 #define ITEM_NAME_SPEED "速度"
 #define ITEM_NAME_DIFF "増分"
 
@@ -57,7 +63,7 @@ enum{
 #define ITEM_NAME_DRAWOUT    "抽出"
 #define ITEM_NAME_RELOAD    "再読み込み"
 #define ITEM_NAME_STOPLOADING "読み込み中止"
-#define ITEM_NAME_FAVORITE  "お気に入りに追加"
+#define ITEM_NAME_APPENDFAVORITE  "お気に入りに追加"
 #define ITEM_NAME_FAVORITE_ARTICLE  "スレをお気に入りに追加"
 #define ITEM_NAME_CHECK_UPDATE_ROOT "サイドバー更新チェック"
 #define ITEM_NAME_CHECK_UPDATE_OPEN_ROOT "サイドバー更新チェックして開く"
@@ -70,8 +76,8 @@ enum{
 
 #define ITEM_NAME_DELETE    "削除"
 #define ITEM_NAME_QUIT      "閉じる"
-#define ITEM_NAME_PREVVIEW  "前へ戻る"
-#define ITEM_NAME_NEXTVIEW  "次へ進む"
+#define ITEM_NAME_BACK  "前へ戻る"
+#define ITEM_NAME_FORWARD  "次へ進む"
 #define ITEM_NAME_LOCK      "タブをロックする"
 #define ITEM_NAME_LIVE      "実況開始／停止"
 
@@ -80,6 +86,7 @@ enum{
 #define ITEM_NAME_SEARCH_NEXT  "次検索"
 #define ITEM_NAME_SEARCH_PREV  "前検索"
 #define ITEM_NAME_NEXTARTICLE    "次スレ検索"
+#define ITEM_NAME_CLEAR_HIGHLIGHT   "ハイライト解除"
 
 #define ITEM_NAME_INSERTTEXT  "テキストファイル挿入"
 #define ITEM_NAME_LOCK_MESSAGE "書き込み後に閉じない"
@@ -102,8 +109,10 @@ enum{
 #define ITEM_NAME_SELECTDELIMG "選択範囲の画像を削除"
 #define ITEM_NAME_SELECTABONEIMG "選択範囲の画像をあぼ〜ん"
 
+#define ITEM_NAME_PREFERENCEVIEW "プロパティ"
 #define ITEM_NAME_PREF_BOARD     "板のプロパティ"
 #define ITEM_NAME_PREF_THREAD    "スレのプロパティ"
+#define ITEM_NAME_PREF_IMAGE     "画像のプロパティ"
 
 
 // SESSION::get_item_*() の戻り値
@@ -115,6 +124,8 @@ enum
     ITEM_HISTVIEW,
     ITEM_HIST_BOARDVIEW,
     ITEM_HIST_CLOSEVIEW,
+    ITEM_HIST_CLOSEBOARDVIEW,
+    ITEM_HIST_CLOSEIMGVIEW,
     ITEM_ARTICLEVIEW,
     ITEM_IMAGEVIEW,
     ITEM_URL,
@@ -130,6 +141,7 @@ enum
     ITEM_NEW,
     ITEM_SINCE,
     ITEM_LASTWRITE,
+    ITEM_ACCESS,
     ITEM_SPEED,
     ITEM_DIFF,
 
@@ -142,7 +154,7 @@ enum
     ITEM_DRAWOUT,
     ITEM_RELOAD,
     ITEM_STOPLOADING,
-    ITEM_FAVORITE,
+    ITEM_APPENDFAVORITE,
     ITEM_FAVORITE_ARTICLE,
     ITEM_CHECK_UPDATE_ROOT,
     ITEM_CHECK_UPDATE_OPEN_ROOT,
@@ -155,8 +167,8 @@ enum
 
     ITEM_DELETE,
     ITEM_QUIT,
-    ITEM_PREVVIEW,
-    ITEM_NEXTVIEW,
+    ITEM_BACK,
+    ITEM_FORWARD,
     ITEM_LOCK,
     ITEM_LIVE,
 
@@ -165,6 +177,7 @@ enum
     ITEM_SEARCH_NEXT,
     ITEM_SEARCH_PREV,
     ITEM_NEXTARTICLE,
+    ITEM_CLEAR_HIGHLIGHT,
 
     ITEM_INSERTTEXT,
     ITEM_LOCK_MESSAGE,
@@ -187,8 +200,10 @@ enum
     ITEM_SELECTDELIMG,
     ITEM_SELECTABONEIMG,
 
+    ITEM_PREFERENCEVIEW,
     ITEM_PREF_BOARD,
     ITEM_PREF_THREAD,
+    ITEM_PREF_IMAGE,
 
     ITEM_END
 };
@@ -217,12 +232,12 @@ enum
 
 enum
 {
-    AUTORELOAD_MINSEC = 10, // オートリロードの最小秒数
-    MIN_LIVE_RELOAD_SEC = AUTORELOAD_MINSEC, // 実況時の最小リロード間隔
+    AUTORELOAD_MINSEC = 2, // オートリロードの最小秒数
+    MIN_LIVE_RELOAD_SEC = 10, // 実況時の最小リロード間隔
 
-    WAITLOADIMG_SEC = 6, // 画像のロード待ち間隔
+    WAITLOADIMG_SEC = 2, // 画像のロード待ち間隔
 
-    CHECKUPDATE_MINSEC = 300 // 更新チェックの最小秒数
+    CHECKUPDATE_MINSEC = 60 // 更新チェックの最小秒数
 };
 
 
@@ -267,6 +282,8 @@ enum
 #define URL_HISTTHREADVIEW "jdview://histthread"
 #define URL_HISTBOARDVIEW "jdview://histboard"
 #define URL_HISTCLOSEVIEW "jdview://histclose"
+#define URL_HISTCLOSEBOARDVIEW "jdview://histcloseboard"
+#define URL_HISTCLOSEIMGVIEW "jdview://histcloseimg"
 
 #define URL_ALLLOG "jdview://alllog"
 
