@@ -19,6 +19,8 @@
 #include "session.h"
 #include "httpcode.h"
 
+#include "history/historymanager.h"
+
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
 
@@ -294,6 +296,19 @@ void ImageAdmin::command_local( const COMMAND_ARGS& command )
         SKELETON::View* view = get_current_view();
         if( view ) view->scroll_right();
     }
+
+    else if( command.command == "set_imgtab_operating" ){
+
+        if( command.arg1 == "true" ) SESSION::set_tab_operating( get_url(), true );
+        else{
+
+            SESSION::set_tab_operating( get_url(), false );
+
+            if( ! empty() ){
+                update_status_of_all_views();
+            }
+        }
+    }
 }
 
 
@@ -329,6 +344,7 @@ void ImageAdmin::open_view( const COMMAND_ARGS& command )
     }
 
     open_window();
+    update_status_of_all_views();
     switch_img( command.url );
 }
 
@@ -450,11 +466,28 @@ void ImageAdmin::reorder( const std::string& url_from, const std::string& url_to
 #endif    
 
         m_iconbox.reorder_child( *view_from, pos );
+
+        update_status_of_all_views();
     }
 }
 
 
+//
+// 全てのビューのステータス表示内容更新の予約
+//
+void ImageAdmin::update_status_of_all_views()
+{
+    if( SESSION::is_tab_operating( get_url() ) ) return;
 
+#ifdef _DEBUG
+    std::cout << "ImageAdmin::update_status_of_all_views\n";
+#endif    
+
+    std::list< SKELETON::View* >::iterator it_view;
+    for( it_view = m_list_view.begin(); it_view != m_list_view.end(); ++it_view ){
+        if( *it_view ) (*it_view)->set_command( "update_status" );
+    }
+}
 
 
 //
@@ -548,7 +581,10 @@ void ImageAdmin::close_view( const std::string& url )
         close_window();
         CORE::core_set_command( "empty_page", get_url() );
     }
-    else if( ! url_next.empty() ) switch_img( url_next );
+    else if( ! url_next.empty() ){
+        update_status_of_all_views();
+        switch_img( url_next );
+    }
 }
 
 
@@ -593,11 +629,15 @@ void ImageAdmin::close_window()
 //
 void ImageAdmin::close_other_views( const std::string& url )
 {
+    set_command( "set_imgtab_operating", "", "true" );
+
     Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
     for(; it !=  m_iconbox.children().end(); ++it ){
         SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
         if( view && view->get_url() != url ) set_command( "close_view", view->get_url() );
     }
+
+    set_command( "set_imgtab_operating", "", "false" );
 }
 
 
@@ -606,12 +646,16 @@ void ImageAdmin::close_other_views( const std::string& url )
 //
 void ImageAdmin::close_left_views( const std::string& url )
 {
+    set_command( "set_imgtab_operating", "", "true" );
+
     Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
     for(; it !=  m_iconbox.children().end(); ++it ){
         SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
-        if( view->get_url() == url ) return;
+        if( view->get_url() == url ) break;
         if( view ) set_command( "close_view", view->get_url() );
     }
+
+    set_command( "set_imgtab_operating", "", "false" );
 }
 
 
@@ -620,6 +664,8 @@ void ImageAdmin::close_left_views( const std::string& url )
 //
 void ImageAdmin::close_right_views( const std::string& url )
 {
+    set_command( "set_imgtab_operating", "", "true" );
+
     Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
     for(; it !=  m_iconbox.children().end(); ++it ){
         SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
@@ -630,6 +676,8 @@ void ImageAdmin::close_right_views( const std::string& url )
         SKELETON::View* view = dynamic_cast< SKELETON::View* >( it->get_widget() );
         if( view ) set_command( "close_view", view->get_url() );
     }
+
+    set_command( "set_imgtab_operating", "", "false" );
 }
 
 
@@ -642,6 +690,8 @@ void ImageAdmin::close_error_views( const std::string mode )
     std::cout << "ImageAdmin::close_error_views\n";
 #endif
 
+    set_command( "set_imgtab_operating", "", "true" );
+
     Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
     for(; it !=  m_iconbox.children().end(); ++it ){
 
@@ -665,6 +715,8 @@ void ImageAdmin::close_error_views( const std::string mode )
             }
         }
     }
+
+    set_command( "set_imgtab_operating", "", "false" );
 }
 
 
@@ -677,6 +729,8 @@ void ImageAdmin::close_noerror_views()
     std::cout << "ImageAdmin::close_noerror_views\n";
 #endif
 
+    set_command( "set_imgtab_operating", "", "true" );
+
     Gtk::Box_Helpers::BoxList::iterator it = m_iconbox.children().begin();
     for(; it !=  m_iconbox.children().end(); ++it ){
 
@@ -691,6 +745,14 @@ void ImageAdmin::close_noerror_views()
             if( code == HTTP_OK ) set_command( "close_view", url );
         }
     }
+
+    set_command( "set_imgtab_operating", "", "false" );
+}
+
+
+void ImageAdmin::restore_lasttab()
+{
+    HISTORY::restore_history( URL_HISTCLOSEIMGVIEW );
 }
 
 
@@ -993,6 +1055,7 @@ void ImageAdmin::save_all()
 #endif
 
     int overwrite = Gtk::RESPONSE_NO;
+    bool use_name_in_cache = false;
 
     std::list< std::string > list_urls = get_URLs();
 
@@ -1039,6 +1102,11 @@ void ImageAdmin::save_all()
                         if( ! copy_file( url, path_from, path_to ) ) return;
                     }
 
+                    // ファイル名として画像キャッシュでのファイル名を使用
+                    else if( use_name_in_cache ){
+                        if( ! copy_file( url, path_from, path_dir + CACHE::filename_img( url ) ) ) return;
+                    }
+
                     // すべていいえ
                     else if( overwrite == SKELETON::OVERWRITE_NO_ALL ){}
 
@@ -1069,8 +1137,26 @@ void ImageAdmin::save_all()
 
                                     // 名前変更
                                 case Gtk::RESPONSE_YES:
-                                    if( ! DBIMG::save( url, get_win(), path_to ) ) continue;
+                                {
+                                    SKELETON::MsgDiag mdiag_name( get_win(),
+                                                                  "ファイル名として画像キャッシュでのファイル名を使用しますか？\n\nいいえを選ぶとファイル選択ダイアログを開きます。",
+                                                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+
+                                    mdiag_name.add_button( "すべてはい", SKELETON::OVERWRITE_YES_ALL );
+                                    mdiag_name.set_default_response( Gtk::RESPONSE_YES );
+                                    const int ret = mdiag_name.run();
+
+                                    if( ret == Gtk::RESPONSE_YES || ret == SKELETON::OVERWRITE_YES_ALL ){
+
+                                        if( ret == SKELETON::OVERWRITE_YES_ALL ) use_name_in_cache = true;
+                                        if( ! copy_file( url, path_from, path_dir + CACHE::filename_img( url ) ) ) return;
+                                    }
+                                    else{
+
+                                        if( ! DBIMG::save( url, get_win(), path_to ) ) continue;
+                                    }
                                     break;
+                                }
 
                                 default:
                                     break;
