@@ -19,8 +19,11 @@ namespace IMAGE
         gdouble m_y_motion;
         size_t m_length_prev;
         bool m_show_status;
+        bool m_update_status;
         bool m_show_label;
 
+        std::string m_status_local;
+
         int m_pre_width;
         int m_pre_height;
         int m_redraw_count;
@@ -30,6 +33,7 @@ namespace IMAGE
 
       public:
         ImageViewMain( const std::string& url );
+        virtual ~ImageViewMain();
 
         virtual void clock_in();
         virtual void show_view();
@@ -41,7 +45,6 @@ namespace IMAGE
         virtual const bool operate_view( const int control );
 
       protected:
-        virtual void show_status();
 
         virtual Gtk::Menu* get_popupmenu( const std::string& url );
 
@@ -49,6 +52,14 @@ namespace IMAGE
         virtual bool slot_motion_notify( GdkEventMotion* event );
 
       private:
+
+        void set_status_local( const std::string& status ){ m_status_local = status; }
+        const std::string& get_status_local(){ return m_status_local; }
+
+        virtual void show_status();
+        virtual void update_status();
+        void add_tab_number();
+
         void show_instruct_diag();
         void set_label();
         void remove_label();
