@@ -8,6 +8,8 @@
 
 #include "jdlib/miscgtk.h"
 
+#include "config/globalconf.h"
+
 #include "session.h"
 #include "command.h"
 
@@ -15,7 +17,7 @@ using namespace IMAGE;
 
 
 ImageWin::ImageWin()
-    : SKELETON::JDWindow( true ),
+    : SKELETON::JDWindow( CONFIG::get_fold_image() ),
       m_tab( NULL )
 {
 #ifdef _DEBUG
@@ -27,6 +29,8 @@ ImageWin::ImageWin()
     init_win();
     pack_remove_end( false, get_statbar(), Gtk::PACK_SHRINK );
 
+    if( ! CONFIG::get_fold_image() ) set_transient_for( *CORE::get_mainwindow() );
+
     show_all_children();
 }
 
@@ -53,12 +57,12 @@ const int ImageWin::get_y_win()
     return SESSION::get_y_win_img();
 }
 
-void ImageWin::set_x_win( int x )
+void ImageWin::set_x_win( const int x )
 {
     SESSION::set_x_win_img( x );
 }
 
-void ImageWin::set_y_win( int y )
+void ImageWin::set_y_win( const int y )
 {
     SESSION::set_y_win_img( y );
 }
@@ -73,12 +77,12 @@ const int ImageWin::get_height_win()
     return SESSION::get_height_win_img();
 }
 
-void ImageWin::set_width_win( int width )
+void ImageWin::set_width_win( const int width )
 {
     SESSION::set_width_win_img( width );
 }
 
-void ImageWin::set_height_win( int height )
+void ImageWin::set_height_win( const int height )
 {
     SESSION::set_height_win_img( height );
 }
@@ -88,7 +92,7 @@ const bool ImageWin::is_focus_win()
     return SESSION::is_focus_win_img();
 }
 
-void ImageWin::set_focus_win( bool set )
+void ImageWin::set_focus_win( const bool set )
 {
     SESSION::set_focus_win_img( set );
 }
@@ -99,7 +103,7 @@ const bool ImageWin::is_maximized_win()
     return SESSION::is_maximized_win_img();
 }
 
-void ImageWin::set_maximized_win( bool set )
+void ImageWin::set_maximized_win( const bool set )
 {
     SESSION::set_maximized_win_img( set );
 }
@@ -110,7 +114,7 @@ const bool ImageWin::is_iconified_win()
     return SESSION::is_iconified_win_img();
 }
 
-void ImageWin::set_iconified_win( bool set )
+void ImageWin::set_iconified_win( const bool set )
 {
     SESSION::set_iconified_win_img( set );
 }
@@ -122,7 +126,7 @@ const bool ImageWin::is_shown_win()
 }
 
 
-void ImageWin::set_shown_win( bool set )
+void ImageWin::set_shown_win( const bool set )
 {
     SESSION::set_shown_win_img( set );
 }
