@@ -179,7 +179,7 @@ void Core::slot_toggle_since( const int mode )
 
     SESSION::set_col_since_time( mode );
     DBTREE::reset_all_since_date();
-    BOARD::get_admin()->set_command( "relayout_all" );    
+    BOARD::get_admin()->set_command( "relayout_all" );
 }
 
 
@@ -196,7 +196,24 @@ void Core::slot_toggle_write( const int mode )
 
     SESSION::set_col_write_time( mode );
     DBTREE::reset_all_write_date();
-    BOARD::get_admin()->set_command( "relayout_all" );    
+    BOARD::get_admin()->set_command( "relayout_all" );
+}
+
+
+//
+// スレ一覧の最終取得の表示モード
+void Core::slot_toggle_access( const int mode )
+{
+    if( ! m_enable_menuslot ) return;
+    if( SESSION::get_col_access_time() == mode ) return;
+
+#ifdef _DEBUG
+    std::cout << "Core::slot_toggle_access mode = " << mode << std::endl;
+#endif
+
+    SESSION::set_col_access_time( mode );
+    DBTREE::reset_all_access_date();
+    BOARD::get_admin()->set_command( "relayout_all" );
 }
 
 
@@ -407,6 +424,7 @@ void Core::slot_toggle_imgview( const int mode )
     if( SESSION::is_booting() ) return;
     if( ! m_enable_menuslot ) return;
 
+    // imageビューの状態
     int current_mode = IMGVIEW_NO;
 
     if( CONFIG::get_use_image_view() ){
@@ -414,10 +432,15 @@ void Core::slot_toggle_imgview( const int mode )
         else current_mode = IMGVIEW_WINDOW;
     }
 
-    // ビュー使用切り替え
-    if( current_mode == IMGVIEW_NO || current_mode == mode ){
-        CONFIG::set_use_image_view( ! CONFIG::get_use_image_view() );
-        if( ! CONFIG::get_use_image_view() ) IMAGE::get_admin()->set_command( "close_all_views" );
+    if( current_mode == mode ) return;
+
+    // imageビュー使用切り替え
+    if( mode == IMGVIEW_NO ){
+        CONFIG::set_use_image_view( false );
+        IMAGE::get_admin()->set_command( "close_all_views" );
+    }
+    else {
+        CONFIG::set_use_image_view( true );
     }
 
     // ウィンドウ、埋め込みモード切り替え
@@ -620,6 +643,18 @@ void Core::slot_toggle_fold_message()
 }
 
 
+//
+// ツリービューの選択を表示中のビューと同期する
+//
+void Core::slot_toggle_select_item_sync()
+{
+    if( CONFIG::get_select_item_sync() != 0 )
+        CONFIG::set_select_item_sync( 0 ); // 同期しない
+    else
+        CONFIG::set_select_item_sync( 1 ); // 同期する
+}
+
+
 //
 // 書き込みログを保存
 //
@@ -1198,7 +1233,7 @@ void Core::slot_show_sidebarboard()
         && SESSION::get_sidebar_current_url() != URL_HISTBOARDVIEW
         ){
 
-        const std::string tab = "true";
+        const std::string tab = "newtab";
         const std::string mode = "";
         CORE::core_set_command( "open_sidebar_board", SESSION::get_sidebar_current_url(), tab, mode, "0" );
     }
@@ -1234,7 +1269,7 @@ void Core::slot_create_vboard()
 //
 void Core::slot_show_bbs()
 {
-    CORE::core_set_command( "open_board" , DBTREE::url_subject( ENVIRONMENT::get_jdbbs() ), "true" );
+    CORE::core_set_command( "open_board" , DBTREE::url_subject( ENVIRONMENT::get_jdbbs() ), "newtab" );
 }
 
 
@@ -1243,7 +1278,7 @@ void Core::slot_show_bbs()
 //
 void Core::slot_show_old2ch()
 {
-    CORE::core_set_command( "open_board" , DBTREE::url_subject( ENVIRONMENT::get_jd2chlog() ), "true" );
+    CORE::core_set_command( "open_board" , DBTREE::url_subject( ENVIRONMENT::get_jd2chlog() ), "newtab" );
 }
 
 
