@@ -36,7 +36,7 @@ SKELETON::ImgToggleToolButton* MessageToolBarBase::get_button_preview()
 
     if( ! m_button_preview ){
 
-        m_button_preview = Gtk::manage( new SKELETON::ImgToggleToolButton( ICON::THREAD ) );
+        m_button_preview = Gtk::manage( new SKELETON::ImgToggleToolButton( ICON::PREVIEW ) );
         m_button_preview->signal_clicked().connect( sigc::mem_fun( *this, &MessageToolBarBase::slot_toggle_preview ) );
     }
 
@@ -164,7 +164,7 @@ void MessageToolBar::pack_buttons()
             case ITEM_UNDO:
 
                 if( ! m_button_undo ){
-                    m_button_undo = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::UNDO ) );
+                    m_button_undo = Gtk::manage( new SKELETON::ImgToolButton( ICON::UNDO ) );
                     m_button_undo->signal_clicked().connect( sigc::mem_fun( *this, &MessageToolBar::slot_undo_clicked ) );
                 }
 
@@ -176,7 +176,7 @@ void MessageToolBar::pack_buttons()
             case ITEM_INSERTTEXT:
 
                 if( ! m_button_insert_draft ){
-                    m_button_insert_draft = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::OPEN ) );
+                    m_button_insert_draft = Gtk::manage( new SKELETON::ImgToolButton( ICON::INSERTTEXT ) );
                     m_button_insert_draft->signal_clicked().connect( sigc::mem_fun( *this, &MessageToolBar::slot_insert_draft_clicked ) );
                 }
 
