@@ -6,7 +6,7 @@
 #ifndef _ENTRY_H
 #define _ENTRY_H
 
-#include "control.h"
+#include "control/control.h"
 
 #include <gtkmm.h>
 
@@ -24,6 +24,7 @@ namespace SKELETON
 
         // 入力コントローラ
         CONTROL::Control m_control;
+        int m_controlid;
 
       public:
 
