@@ -5,6 +5,7 @@
 
 #include <gtkmm.h>
 #include <string>
+#include <set>
 
 #include "control/control.h"
 
@@ -38,6 +39,7 @@ namespace SKELETON
         // ポップアップメニュー
         Glib::RefPtr< Gtk::ActionGroup > m_action_group;
         Glib::RefPtr< Gtk::UIManager > m_ui_manager;
+        std::set< std::string > m_url_popup;
 
         // ツールバーに表示する文字列
         std::string m_label;
@@ -67,15 +69,25 @@ namespace SKELETON
         // ロック状態
         bool m_locked;
 
+        // 書き込み可能か
+        bool m_writeable;
+
         // ツールバーのID
         int m_id_toolbar;
 
         // 検索文字列
         std::string m_search_query;
 
+        // ポップアップ時に全ての領域を表示できないならカーソルの上に表示
+        bool m_popup_upside;
+
+        // ロード時にキャッシュを削除してからviewを再読み込みする
+        bool m_reget;
+
       protected:
 
-        void set_url( const std::string& url_new, const bool update_history );
+        // url_new に URL を変更
+        void set_url( const std::string& url_new );
 
         // Viewが所属するAdminクラス
         virtual Admin* get_admin() = 0;
@@ -134,6 +146,9 @@ namespace SKELETON
         // ポップアップメニュー表示時に表示位置を決めるスロット
         void slot_popup_menu_position( int& x, int& y, bool& push_in );
 
+        // ポップアップメニューがmapした時に呼び出されるスロット
+        void slot_map_popupmenu();
+
         // ポップアップメニューがhideした時に呼び出されるスロット
         void slot_hide_popupmenu();
 
@@ -151,13 +166,16 @@ namespace SKELETON
         View( const std::string& url, const std::string& arg1 = std::string(), const std::string& arg2 = std::string() );
         virtual ~View(){}
 
+        virtual void save_session() = 0;
+
         virtual const std::string& get_url(){ return m_url; }
+        const std::string& get_url_admin();
 
         virtual void set_parent_win( Gtk::Window* parent_win ){ m_parent_win = parent_win; }
         virtual Gtk::Window* get_parent_win(){ return m_parent_win; }
 
         // 移転があったときなどにadminから呼び出される
-        void update_url( const std::string& url_old, const std::string& url_new );
+        virtual void update_url( const std::string& url_old, const std::string& url_new );
 
         // 検索文字列
         const std::string& get_search_query(){ return m_search_query; }
@@ -175,6 +193,14 @@ namespace SKELETON
         virtual void lock(){ m_locked = true; }
         virtual void unlock(){ m_locked = false; }
 
+        // 書き込み可能/不可能
+        const bool is_writeable() const { return m_writeable; }
+        void set_writeable( const bool writeable ){ m_writeable = writeable; }
+
+        // ポップアップ時に全ての領域を表示できないならカーソルの上に表示
+        const bool get_popup_upside() const { return m_popup_upside; }
+        void set_popup_upside( const bool upside ){ m_popup_upside = upside; }
+
         // view 上にマウスポインタがあれば true
         const bool is_mouse_on_view();
 
@@ -211,6 +237,10 @@ namespace SKELETON
         // 現在のオートリロードのモード取得
         const int get_autoreload_mode() const { return m_autoreload_mode; }
 
+        // ロード時にキャッシュを削除してからviewを再読み込みする
+        const bool get_reget() const{ return m_reget; }
+        void set_reget( const bool reget ){ m_reget = reget; }
+
         // アイコンのID取得
         virtual const int get_icon( const std::string& iconname ){ return -1; }
 
@@ -229,8 +259,11 @@ namespace SKELETON
         // 壊れているか
         virtual const bool is_broken(){ return false; }
 
-        // shutdown( SIGHUP )用
-        virtual void shutdown(){}
+        // ラベルやステータスバーの色
+        const std::string get_color();
+
+        // キーを押した
+        virtual const bool slot_key_press( GdkEventKey* event ){ return false; }
 
         // クロック入力
         // clock_in()はビューがアクティブのときに呼び出される
@@ -256,7 +289,7 @@ namespace SKELETON
         virtual const bool operate_view( const int ) = 0;
         virtual void goto_top(){}
         virtual void goto_bottom(){}
-        virtual void goto_num( int num ){}
+        virtual void goto_num( const int num_to, const int num_from ){}
         virtual void scroll_up(){}
         virtual void scroll_down(){}
         virtual void scroll_left(){}
