@@ -449,6 +449,7 @@ void Dom::parse( const Gtk::TreeModel::Children& children, SKELETON::EditColumns
         const Glib::ustring url = row[ columns.m_url ];
         const Glib::ustring data = row[ columns.m_data ];
         const Glib::ustring name = row[ columns.m_name ];
+        const size_t dirid = row[ columns.m_dirid ];
         const bool expand = row[ columns.m_expand ];
 
         if( type != TYPE_UNKNOWN )
@@ -463,6 +464,7 @@ void Dom::parse( const Gtk::TreeModel::Children& children, SKELETON::EditColumns
                 if( ! name.empty() ) node->setAttribute( "name", name );
                 if( ! url.empty() ) node->setAttribute( "url", url );
                 if( ! data.empty() ) node->setAttribute( "data", data );
+                if( dirid ) node->setAttribute( "dirid", dirid );
 
                 // 再帰
                 if( ! row.children().empty() ) node->parse( row.children(), columns );
@@ -507,11 +509,15 @@ void Dom::append_treestore( Glib::RefPtr< Gtk::TreeStore >& treestore,
                 else row = *( treestore->append() );
 
                 // 各値をセット
-                columns.setup_row( row, (*it)->getAttribute( "url" ), (*it)->getAttribute( "name" ), (*it)->getAttribute( "data" ), type );
+                columns.setup_row( row, (*it)->getAttribute( "url" ), (*it)->getAttribute( "name" ), (*it)->getAttribute( "data" ), type, 0 );
 
-                // 開いているツリーを追加
-                if( type == TYPE_DIR
-                 && (*it)->getAttribute( "open" ) == "y" ) list_path_expand.push_back( treestore->get_path( row ) );
+                if( type == TYPE_DIR ){
+
+                    row[ columns.m_dirid ] = atoi( (*it)->getAttribute( "dirid" ).c_str() );
+
+                    // 開いているツリーを追加
+                    if( (*it)->getAttribute( "open" ) == "y" ) list_path_expand.push_back( treestore->get_path( row ) );
+                }
 
                 // 再帰
                 if( (*it)->hasChildNodes() ) (*it)->append_treestore( treestore, columns, list_path_expand, row );
